<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\FuncionariosHierarqService;
use FM\Traits\TResponse;

class FuncionariosHierarqController extends FMCrud {

    use TResponse;

    protected $dataSourceName = 'fcm_checklistagend';
    protected $FuncionariosHierarqService;
   
    public function __construct($crudService, $environment, FuncionariosHierarqService $FuncionariosHierarqService) {
        parent::__construct($crudService, $environment);
        $this->FuncionariosHierarqService = $FuncionariosHierarqService;
    }
    
    // Busca toda a ramificação de usuários da hierarquia
    public function getHierarchyDetails(DTO\Request $request, DTO\Response $response) {
        $nrhierarquiafunc = $request->getParameters();

        $var = $this->FuncionariosHierarqService->getHierarchyDetails($nrhierarquiafunc['nrhierarquiafunc']);

        $dtsVal = new DataSet('info',$var);
        $response->addDataSet($dtsVal);
    }

    public function getHierarquiaFacilities(Request $request, Response $response) {
        try {
                $data = $this->FuncionariosHierarqService->getHierarquiaFacilities($request->getParameters());
                $this->sendResponse($data, 200);
            } catch (Exception $ex) {
                $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            }
    }

    // Busca uma lista personalizada de usuários que podem ser adicionados na hierarquia
    public function getHierarchyUsers(DTO\Request $request, DTO\Response $response) {
        $nrhierarquiafunc = $request->getParameters();

        $var = $this->FuncionariosHierarqService->getHierarchyUsers($nrhierarquiafunc['nrhierarquiafunc']);

        $dtsVal = new DataSet('info',$var);
        $response->addDataSet($dtsVal);
    }
    
    // Busca uma lista personalizada de usuários que podem ser Pais na hierarquia
    public function getHierarchyUsersParents(DTO\Request $request, DTO\Response $response) {
        $nrhierarquiafunc = $request->getParameters();

        $var = $this->FuncionariosHierarqService->getHierarchyUsersParents($nrhierarquiafunc['nrhierarquiafunc']);

        $dtsVal = new DataSet('info',$var);
        $response->addDataSet($dtsVal);
    }
    
    // Insere um novo usuário à hierarquia
    public function insertHierarchyUser(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $var = $this->FuncionariosHierarqService->insertHierarchyUser($params);

        $dtsVal = new DataSet('info', array('error' => $var));
        $response->addDataSet($dtsVal);
    }
    
    // Deleta um usuário e sua ramificação abaixo
    public function deleteHierarchyUser(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        $var = $this->FuncionariosHierarqService->deleteHierarchyUser($params);

        $dtsVal = new DataSet('info', array('error' => $var));
        $response->addDataSet($dtsVal);
    }
    
}
?>